@@ -16,7 +16,7 @@
 
 """Viewer for NFO files."""
 
-__version__ = "1.2.1"
+__version__ = "1.6"
 
 from nfoview.errors import *
 from nfoview.unittest import *
@@ -27,6 +27,7 @@ from nfoview.conf import *
 conf = Configuration()
 conf.read_from_file()
 from nfoview import schemes
+from nfoview.builder import *
 from nfoview.about import *
 from nfoview.open import *
 from nfoview.preferences import *
