@@ -17,17 +17,17 @@
 """Internationalization functions."""
 
 import gettext
-import gtk.glade
 import locale
 import nfoview
 
 __all__ = ("_", "dgettext", "ngettext")
 
 locale.setlocale(locale.LC_ALL, "")
+locale.bindtextdomain("nfoview", nfoview.LOCALE_DIR)
+locale.textdomain("nfoview")
+
 gettext.bindtextdomain("nfoview", nfoview.LOCALE_DIR)
-gtk.glade.bindtextdomain("nfoview", nfoview.LOCALE_DIR)
 gettext.textdomain("nfoview")
-gtk.glade.textdomain("nfoview")
 
 _ = gettext.gettext
 dgettext = gettext.dgettext
